@@ -13,7 +13,7 @@ use Pod::Usage qw< pod2usage >;
 
 use Perl::ToPerl6::Exception::Parse ();
 use Perl::ToPerl6::Utils qw<
-    :characters :severities policy_short_name
+    :characters :severities transformer_short_name
     $DEFAULT_VERBOSITY $DEFAULT_VERBOSITY_WITH_FILE_NAME
 >;
 use Perl::ToPerl6::Utils::Constants qw< $_MODULE_VERSION_TERM_ANSICOLOR >;
@@ -127,11 +127,11 @@ sub _dispatch_special_requests {
     if ( $opts{-options}         ) { pod2usage( -verbose => 1 )    }  # Exits
     if ( $opts{-man}             ) { pod2usage( -verbose => 2 )    }  # Exits
     if ( $opts{-version}         ) { _display_version()            }  # Exits
-    if ( $opts{-list}            ) { _render_all_policy_listing()  }  # Exits
-    if ( $opts{'-list-enabled'}  ) { _render_policy_listing(%opts) }  # Exits
+    if ( $opts{-list}            ) { _render_all_transformer_listing()  }  # Exits
+    if ( $opts{'-list-enabled'}  ) { _render_transformer_listing(%opts) }  # Exits
     if ( $opts{'-list-themes'}   ) { _render_theme_listing()       }  # Exits
     if ( $opts{'-profile-proto'} ) { _render_profile_prototype()   }  # Exits
-    if ( $opts{-doc}             ) { _render_policy_docs( %opts )  }  # Exits
+    if ( $opts{-doc}             ) { _render_transformer_docs( %opts )  }  # Exits
     return 1;
 }
 
@@ -431,19 +431,19 @@ sub _report_statistics {
 
         _out "\n";
 
-        my %policy_transformations = %{ $statistics->transformations_by_policy() };
-        my @transformers = sort keys %policy_transformations;
+        my %transformer_transformations = %{ $statistics->transformations_by_transformer() };
+        my @transformers = sort keys %transformer_transformations;
         $width =
             max
-                map { length _commaify( $policy_transformations{$_} ) }
+                map { length _commaify( $transformer_transformations{$_} ) }
                     @transformers;
-        foreach my $policy (@transformers) {
+        foreach my $transformer (@transformers) {
             _out
                 sprintf
                     "%*s transformations of %s.\n",
                     $width,
-                    _commaify($policy_transformations{$policy}),
-                    policy_short_name($policy);
+                    _commaify($transformer_transformations{$transformer}),
+                    transformer_short_name($transformer);
         }
     }
 
@@ -494,7 +494,7 @@ sub _get_option_specification {
         profile-proto
         quiet
         severity=i
-        single-policy|s=s
+        single-transformer|s=s
         stern
         statistics!
         statistics-only!
@@ -568,15 +568,15 @@ sub _at_tty {
 
 #-----------------------------------------------------------------------------
 
-sub _render_all_policy_listing {
-    # Force P-C parameters, to catch all Policies on this site
+sub _render_all_transformer_listing {
+    # Force P-C parameters, to catch all Transformers on this site
     my %pc_params = (-profile => $EMPTY, -severity => $SEVERITY_LOWEST);
-    return _render_policy_listing( %pc_params );
+    return _render_transformer_listing( %pc_params );
 }
 
 #-----------------------------------------------------------------------------
 
-sub _render_policy_listing {
+sub _render_transformer_listing {
     my %pc_params = @_;
 
     require Perl::ToPerl6::TransformerListing;
@@ -621,7 +621,7 @@ sub _render_profile_prototype {
 
 #-----------------------------------------------------------------------------
 
-sub _render_policy_docs {
+sub _render_transformer_docs {
 
     my (%opts) = @_;
     my $pattern = delete $opts{-doc};
@@ -631,7 +631,7 @@ sub _render_policy_docs {
     _set_up_pager($mogrify->config()->pager());
 
     require Perl::ToPerl6::TransformerFactory;
-    my @site_transformers  = Perl::ToPerl6::TransformerFactory->site_policy_names();
+    my @site_transformers  = Perl::ToPerl6::TransformerFactory->site_transformer_names();
     my @matching_transformers  = grep { /$pattern/ixms } @site_transformers;
 
     # "-T" means don't send to pager
