@@ -48,22 +48,22 @@ sub transform_ok {
     my $subtests_with_extras =  subtests_in_tree( 't', 'include extras' );
 
     my $subtests = [];
-    my $in_sample;
+    my $in_expected;
     for my $line (<$fh>) {
         chomp $line;
         if ( $line =~ /^## name: (.+)/ ) {
-            $in_sample = undef;
+            $in_expected = undef;
             push @{ $subtests }, {
                 name => $1,
                 failures => 0,
                 lineno   => 1,
                 parms    => {},
                 original => [],
-                sample => [],
+                expected => [],
             }
         }
-        elsif ( $line eq '##-->' ) { $in_sample = 1 }
-        elsif ( $in_sample ) { push @{ $subtests->[-1]{sample} }, $line }
+        elsif ( $line eq '##-->' ) { $in_expected = 1 }
+        elsif ( $in_expected ) { push @{ $subtests->[-1]{expected} }, $line }
         else {
             unless ( $subtests and @{ $subtests } ) {
                 $TEST->ok( 0, 'Test formatted correctly' );
@@ -73,22 +73,21 @@ sub transform_ok {
         }
     }
 
-    $TEST->plan( tests => 1 );
     $TEST->note("Running tests for transformer: $transformer");
 
-    my ($full_policy_name, $method) =
+    my ($full_transformer_name, $method) =
         ("Perl::ToPerl6::Transformer::$transformer", 'transform');
-    my $can_ok_label = qq{Class '$full_policy_name' has method '$method'};
-    $TEST->ok( $full_policy_name->can($method), $can_ok_label );
+    my $can_ok_label = qq{Class '$full_transformer_name' has method '$method'};
+    $TEST->ok( $full_transformer_name->can($method), $can_ok_label );
 
     for my $subtest ( @{ $subtests } ) {
         my $todo = $subtest->{TODO};
         if ($todo) { $TEST->todo_start( $todo ); }
 
         my ($error, @transformations) = _run_subtest($transformer, $subtest);
+        $TEST->ok( !$error, _create_test_name($transformer, $subtest) );
 #        my ($ok, @diag)=
 #            _evaluate_test_results($subtest, $error, \@transformations);
-#        $TEST->ok( $ok, _create_test_name($transformer, $subtest) );
 #
 #        if (@diag) { $TEST->diag(@diag); }
 #        if ($todo) { $TEST->todo_end(); }
@@ -107,7 +106,7 @@ sub all_transformers_ok {
     my $subtests_with_extras =  subtests_in_tree( $test_dir, 'include extras' );
 
     if ($wanted_transformers) {
-        _validate_wanted_policy_names($wanted_transformers, $subtests_with_extras);
+        _validate_wanted_transformer_names($wanted_transformers, $subtests_with_extras);
         _filter_unwanted_subtests($wanted_transformers, $subtests_with_extras);
     }
 
@@ -116,19 +115,19 @@ sub all_transformers_ok {
     my $transformers_to_test = join q{, }, keys %{$subtests_with_extras};
     $TEST->note("Running tests for transformers: $transformers_to_test");
 
-    for my $policy ( sort keys %{$subtests_with_extras} ) {
+    for my $transformer ( sort keys %{$subtests_with_extras} ) {
 
-	    my ($full_policy_name, $method) = ("Perl::ToPerl6::Transformer::$policy", 'transform');
-	    my $can_ok_label = qq{Class '$full_policy_name' has method '$method'};
-	    $TEST->ok( $full_policy_name->can($method), $can_ok_label );
+	    my ($full_transformer_name, $method) = ("Perl::ToPerl6::Transformer::$transformer", 'transform');
+	    my $can_ok_label = qq{Class '$full_transformer_name' has method '$method'};
+	    $TEST->ok( $full_transformer_name->can($method), $can_ok_label );
 
-	    for my $subtest ( @{ $subtests_with_extras->{$policy}{subtests} } ) {
+	    for my $subtest ( @{ $subtests_with_extras->{$transformer}{subtests} } ) {
 		    my $todo = $subtest->{TODO};
 		    if ($todo) { $TEST->todo_start( $todo ); }
 
-		    my ($error, @transformations) = _run_subtest($policy, $subtest);
+		    my ($error, @transformations) = _run_subtest($transformer, $subtest);
 #		    my ($ok, @diag)= _evaluate_test_results($subtest, $error, \@transformations);
-#		    $TEST->ok( $ok, _create_test_name($policy, $subtest) );
+#		    $TEST->ok( $ok, _create_test_name($transformer, $subtest) );
 #
 #		    if (@diag) { $TEST->diag(@diag); }
 #		    if ($todo) { $TEST->todo_end(); }
@@ -140,7 +139,7 @@ sub all_transformers_ok {
 
 #-----------------------------------------------------------------------------
 
-sub _validate_wanted_policy_names {
+sub _validate_wanted_transformer_names {
     my ($wanted_transformers, $subtests_with_extras) = @_;
     return 1 if not $wanted_transformers;
     my @all_testable_transformers = keys %{ $subtests_with_extras };
@@ -185,34 +184,36 @@ sub __markup_array {
 sub __results_string {
     my ($subtest, $error_line) = @_;
 
-    # Sigh, for the moment just walk the strings. ^ should work...
-    #
     my $offset;
-    for ( 0 .. length($subtest->{sample}[$error_line]) ) {
-        next if substr($subtest->{sample}[$error_line], $_, 1 ) eq
-                substr($subtest->{transformed}[$error_line], $_, 1 );
-        $offset = $_ + 1;
-        last;
+    if ( $error_line ) {
+        # Sigh, for the moment just walk the strings. ^ should work...
+        #
+        for ( 0 .. length($subtest->{expected}[$error_line]) ) {
+            next if substr($subtest->{expected}[$error_line], $_, 1 ) eq
+                    substr($subtest->{got}[$error_line], $_, 1 );
+            $offset = $_ + 1;
+            last;
+        }
     }
 
     join( "\n", __markup_array( $subtest->{original}, $error_line ),
                 '====??====>',
-                __markup_array( $subtest->{sample}, $error_line, $offset ),
+                __markup_array( $subtest->{expected}, $error_line, $offset ),
                 '====!!====>',
-                __markup_array( $subtest->{transformed}, $error_line, $offset )
+                __markup_array( $subtest->{got}, $error_line, $offset )
     );
 }
 
 sub __is_deeply {
-    my ($policy, $subtest) = @_;
+    my ($transformer, $subtest) = @_;
 
-    my $num_errors;
-    my $last_line = min( $#{ $subtest->{sample} },
-                         $#{ $subtest->{transformed} } );
+    my $error_line = 0;
+    my $last_line = min( $#{ $subtest->{expected} },
+                         $#{ $subtest->{got} } );
     my $first_different_line = 0;
     for my $idx ( 0 .. $last_line ) {
-        next if $subtest->{sample}[$idx] eq
-                $subtest->{transformed}[$idx];
+        next if $subtest->{expected}[$idx] eq
+                $subtest->{got}[$idx];
         $first_different_line = $idx;
         $TEST->diag(
             "Output begins to differ at line " .
@@ -220,32 +221,33 @@ sub __is_deeply {
             ":\n" .
             __results_string($subtest, $first_different_line)
         );
-        $num_errors++;
+        $error_line = $first_different_line;
         last;
     }
 
-    if ( $#{ $subtest->{sample} } > $#{ $subtest->{transformed} } ) {
+    if ( $#{ $subtest->{expected} } > $#{ $subtest->{got} } ) {
         warn "Error was [$@]\n" if $@;
         $TEST->diag(
             "Transformed file missing lines from original:\n".
             __results_string($subtest)
         );
-        $num_errors++;
+        $error_line = $#{ $subtest->{got} };
     }
-    elsif ( $#{ $subtest->{sample} } < $#{ $subtest->{transformed} } ) {
+    elsif ( $#{ $subtest->{expected} } < $#{ $subtest->{got} } ) {
         $TEST->diag(
             "Transformed file has more lines than original:\n".
             __results_string($subtest)
         );
-        $num_errors++;
+        $error_line = $#{ $subtest->{expected} };
     }
-    return $num_errors;
+    $subtest->{lineno} = $error_line + 1;
+    return $error_line;
 }
 
 #-----------------------------------------------------------------------------
 
 sub _run_subtest {
-    my ($policy, $subtest) = @_;
+    my ($transformer, $subtest) = @_;
 
     my $document;
     my @transformations;
@@ -254,7 +256,7 @@ sub _run_subtest {
         eval {
             @transformations =
                 ftransform_with_transformations(
-                    $policy,
+                    $transformer,
                     \$subtest->{code},
                     $subtest->{filename},
                     $subtest->{parms},
@@ -268,7 +270,7 @@ sub _run_subtest {
         eval {
             ($document, @transformations) =
                 ptransform_with_transformations(
-                    $policy,
+                    $transformer,
                     $subtest->{original},
                     $subtest->{parms},
                 );
@@ -278,17 +280,13 @@ sub _run_subtest {
         };
     }
     if ( $document ) {
-        $subtest->{transformed} = [split /\n/,$document];
+        $subtest->{got} = [split /\n/,$document];
     }
     else {
         die "*** caught error $error!\n";
     }
-    my $num_errors = __is_deeply($policy, $subtest);
-
-    if ( $num_errors ) {
-        $TEST->ok(0==1, "$policy - $subtest->{name} - failed");
-    }
-    return;
+    my $num_errors = __is_deeply($transformer, $subtest);
+    return $num_errors;
 }
 
 #-----------------------------------------------------------------------------
@@ -349,7 +347,7 @@ sub _evaluate_error_case {
 sub _compute_test_count {
     my ($subtests_with_extras) = @_;
 
-    # one can_ok() for each policy
+    # one can_ok() for each transformer
     my $ntransformers = scalar keys %{ $subtests_with_extras };
 
     my $nsubtests = 0;
@@ -382,8 +380,8 @@ sub _all_optional_modules_are_available {
 #-----------------------------------------------------------------------------
 
 sub _create_test_name {
-    my ($policy, $subtest) = @_;
-    return join ' - ', $policy, "line $subtest->{lineno}", $subtest->{name};
+    my ($transformer, $subtest) = @_;
+    return join ' - ', $transformer, "line $subtest->{lineno}", $subtest->{name};
 }
 
 #-----------------------------------------------------------------------------
@@ -399,7 +397,7 @@ __END__
 
 =head1 NAME
 
-Test::Perl::ToPerl6::Transformer - A framework for testing your custom Policies
+Test::Perl::ToPerl6::Transformer - A framework for testing your custom Transformers
 
 =head1 SYNOPSIS
 
@@ -417,8 +415,8 @@ Test::Perl::ToPerl6::Transformer - A framework for testing your custom Policies
     # If you want your test program to accept short Transformer names as
     # command-line parameters...
     #
-    # You can then test a single policy by running
-    # "perl -Ilib t/policy-test.t My::Transformer".
+    # You can then test a single transformer by running
+    # "perl -Ilib t/transformer-test.t My::Transformer".
     my %args = @ARGV ? ( -transformers => [ @ARGV ] ) : ();
     all_transformers_ok(%args);
 
@@ -441,13 +439,13 @@ against this module until it has stabilized.
 
 =over
 
-=item all_transformers_ok('-test-directory' => $path, -transformers => \@policy_names)
+=item all_transformers_ok('-test-directory' => $path, -transformers => \@transformer_names)
 
 Loads all the F<*.run> files beneath the C<-test-directory> and runs the
 tests.  If C<-test-directory> is not specified, it defaults to F<t/>.
 C<-transformers> is an optional reference to an array of shortened Transformer names.
-If C<-transformers> specified, only the tests for Policies that match one of the
-C<m/$POLICY_NAME/imx> will be run.
+If C<-transformers> specified, only the tests for Transformers that match one
+of the C<m/$POLICY_NAME/imx> will be run.
 
 
 =back
@@ -455,7 +453,7 @@ C<m/$POLICY_NAME/imx> will be run.
 
 =head1 CREATING THE *.run FILES
 
-Testing a policy follows a very simple pattern:
+Testing a transformer follows a very simple pattern:
 
     * Transformer name
         * Subtest name
@@ -464,10 +462,10 @@ Testing a policy follows a very simple pattern:
         * Optional exception expected
         * Optional filename for code
 
-Each of the subtests for a policy is collected in a single F<.run>
+Each of the subtests for a transformer is collected in a single F<.run>
 file, with test properties as comments in front of each code block
 that describes how we expect Perl::ToPerl6 to react to the code.  For
-example, say you have a policy called Variables::ProhibitVowels:
+example, say you have a transformer called Variables::ProhibitVowels:
 
     (In file t/Variables/ProhibitVowels.run)
 
@@ -506,7 +504,7 @@ make a C<##TODO> entry.
 
     ## TODO Should pass when PPI 1.xxx comes out
 
-If the code is expected to trigger an exception in the policy,
+If the code is expected to trigger an exception in the transformer,
 indicate that like so:
 
     ## error 1
@@ -516,7 +514,7 @@ indicate a C<like()> test:
 
     ## error /Can't load Foo::Bar/
 
-If the policy you are testing cares about the filename of the code,
+If the transformer you are testing cares about the filename of the code,
 you can indicate that C<ftransform> should be used like so (see
 C<ftransform> for more details):
 
@@ -534,12 +532,12 @@ keywords in the file footer from producing false positives or negatives in the
 last test.
 
 Note that nowhere within the F<.run> file itself do you specify the
-policy that you're testing.  That's implicit within the filename.
+transformer that you're testing.  That's implicit within the filename.
 
 
 =head1 BUGS AND CAVEATS AND TODO ITEMS
 
-Add policy_ok() method for running subtests in just a single TODO file.
+Add transformer_ok() method for running subtests in just a single TODO file.
 
 Can users mark this entire test as TODO or SKIP, using the normal mechanisms?
 
